[intel-hda] Typo fixes.

TEST: No behavior change
Change-Id: I763d20eba36417aaba62c0b6f33ce8b75ca4aab5
diff --git a/system/ulib/intel-hda/codec-utils/debug-logging.h b/system/ulib/intel-hda/codec-utils/debug-logging.h
index f6c4c14..053fb6d 100644
--- a/system/ulib/intel-hda/codec-utils/debug-logging.h
+++ b/system/ulib/intel-hda/codec-utils/debug-logging.h
@@ -9,7 +9,7 @@
 
 // TODO(johngro) : replace this with a system which...
 //
-// 1) Uses low overhead loging service infrastructure instead of printf.
+// 1) Uses low overhead logging service infrastructure instead of printf.
 // 2) Uses C/C++ functions (either template parameter packs, or c-style
 //    var-args) instead of preprocessor macros.
diff --git a/system/ulib/intel-hda/codec-utils/codec-driver-base.cpp b/system/ulib/intel-hda/codec-utils/codec-driver-base.cpp
index ec9e2c5..8ef1730 100644
--- a/system/ulib/intel-hda/codec-utils/codec-driver-base.cpp
+++ b/system/ulib/intel-hda/codec-utils/codec-driver-base.cpp
@@ -221,7 +221,7 @@
     }
 
     if (resp_size < sizeof(resp.hdr)) {
-        DEBUG_LOG("Bad length (%u) reading from device channel (expectd at least %zu)!\n",
+        DEBUG_LOG("Bad length (%u) reading from device channel (expected at least %zu)!\n",
                   resp_size, sizeof(resp.hdr));
         return ZX_ERR_INVALID_ARGS;
     }
@@ -247,13 +247,13 @@
             if (!payload.unsolicited())
                 return ProcessSolicitedResponse(payload);
 
             // If this is an unsolicited reponse, check to see if the tag is
             // owned by a stream or not.  If it is, dispatch the payload to the
             // stream, otherwise give it to the codec.
             uint32_t stream_id;
             zx_status_t res = MapUnsolTagToStreamId(payload.unsol_tag(), &stream_id);
             if (res != ZX_OK) {
-                DEBUG_LOG("Received unexpected unsolicited reponse (tag %u)\n",
+                DEBUG_LOG("Received unexpected unsolicited response (tag %u)\n",
                           payload.unsol_tag());
                 return ZX_OK;
             }
@@ -263,7 +263,7 @@
 
             auto stream = GetActiveStream(stream_id);
             if (stream == nullptr) {
-                DEBUG_LOG("Received unsolicited reponse (tag %u) for inactive stream (id %u)\n",
+                DEBUG_LOG("Received unsolicited response (tag %u) for inactive stream (id %u)\n",
                           payload.unsol_tag(), stream_id);
                 return ZX_OK;
             } else {
@@ -406,7 +406,7 @@
         device_channel = device_channel_;
     }
 
-    // Add this channel to the set of active channels.  If we encounte a key
+    // Add this channel to the set of active channels.  If we encounter a key
     // collision, then something is wrong with our codec driver implementation.
     // Fail the activation.
     {
@@ -247,13 +247,13 @@
                 return ProcessSolicitedResponse(payload);
 
-            // If this is an unsolicited reponse, check to see if the tag is
+            // If this is an unsolicited response, check to see if the tag is
             // owned by a stream or not.  If it is, dispatch the payload to the
             // stream, otherwise give it to the codec.